@@ -3,7 +3,8 @@ use ::bevy::prelude::*;
 use bevy_websocket_adapter::{
     bevy::{WebSocketServer, WsMessageInserter},
     impl_message_type,
-    server::{ConnectionHandle, Server},
+    shared::ConnectionHandle,
+    server::Server,
 };
 use log::info;
 
@@ -35,7 +36,7 @@ fn main() {
         .add_plugins(MinimalPlugins)
         .add_plugin(WebSocketServer::default())
         .add_startup_system(start_listen.system())
-        .register_message_type::<Ping>()
+        .add_message_type::<Ping>()
         .add_system(respond_to_pings.system())
         .run();
 }
